---
output: 
  html_document:
    template: texty.html 
    code_folding: hide # fold code chunks by default
    keep_md: false # generate a markdown version too
    self_contained: false # don't create single file
    md_extensions: -autolink_bare_uris # dont add <a> to any url in text
    
    
    
page_url: http://texty.org.ua/d/auto_euro/ 
page_title: Порівняння ціни для авто з українською реєстрацією та на "єврономерах"  # name in title of a page
description: Ми порівняли десятки тисяч цінових пропозицій для автомобілів на єврономерах та з українською реєстрацією. Які машини найбільш популярні, яка різниця в ціні - про це та інше читайте у нашому матеріалі
title: Тому що дешевше, дурнику # name for article
subtitle: "Секрет популярності машин на 'єврономерах' дуже простий: через державну фіскальну політику за одні й ті самі гроші можна придбати майже на десять років 'молодшу' машину. Саме з цієї причини, попри усі ризики, громадяни вважають за краще купувати авто без української реєстрації"
authors: "Автор: Анатолій Бондаренко"
published: "Опубліковано: 13 лютого 2018 року"
knit: (function(inputFile, encoding) { rmarkdown::render(inputFile, encoding = encoding, output_file = file.path(dirname(inputFile), 'index.html')) }) # this is a hack to create index.html from Rmd file with different name 



css:
- css/bootstrap.min.css
- css/application.css

libs:
- lib/share-behavior.js
- lib/bootstrap.min.js

---

```{r echo=FALSE}
#
#
#
#    README FIRST! To reproduce this report, please:
# 1. Download and install R and RStudio https://www.rstudio.com/
# 2. download data from here: http://texty.org.ua/d/auto_euro/data/data.zip
# 3. in your base directory (with this script) create subdirectory "data", copy datafiles to it
# 4. start execution of this script
#
#
#
```




```{r setup, include=FALSE, echo=FALSE, message=FALSE, warning=FALSE}
# need script_new.R to load all data



library(readr)
library(tidyverse)
library(hrbrthemes)
source("../functions.R")

ua_new <- "./data/offers_ua_new.csv"
ua_old <- "./data/offers_ua_old.csv"
eu_new <- "./data/offers_eu_new.csv"
eu_old <- "./data/offers_eu_old.csv"
# put data into subdirectory "data" relative to this script
df_ua_new <- anonymise_df( read_csv(ua_new), ua_new)
df_ua_old <- anonymise_df( read_csv(ua_old), ua_old)

df_eu_new <- anonymise_df( read_csv(eu_new), eu_new)
df_eu_old <- anonymise_df( read_csv(eu_old), eu_old)

img_dir <- 'img/'
plot_bg <- "#fbf7f3"

```



Автівки на “євробляхах”, або на “єврономерах”, вони ж “поляки”, “литовці”, “латвійці” стали занадто помітним явищем[^1]: їх багато, їхні власники створюють рухи на свій захист, їх звинувачують в усіх гріхах на дорогах, вони викликають складні почуття у водіїв машин з українською реєстрацією – від люті до легкого роздратування і думок, чи не продати свою і купити натомість щось краще “з Європи”.

Ми вирішили дослідити суто економічну складову питання – ринок таких автівок у порівнянні з “офіційними”. Для цього впродовж останнього року ми отримали декілька сотень тисяч пропозицій з продажу, розміщених на одному з популярних сайтів автомобільних оголошень[^2], та зробили аналіз цих даних[^3]. Ось що ми побачили:


### Вік машин

На малюнку нижче ми показали машини без української реєстрації (зображені синім кольором), та зареєстровані в Україні (червоним). Видно, що вік машин сильно відрізняється (дані на графіку станом на січень 2018 року). Що означає графік розподілу: чим вище графік в точці для якогось року, тим більше таких автівок на ринку.

Для машин на українських номерах є два помітні піки, які припадають на 2007 та 2012 роки. Виходить, що саме автівки з віком у 10 та 5 років, відповідно, продаються на вторинному ринку найчастіше.

Натомість, пік кількості “євроблях”, що продаються, припадає на автівки приблизно 2000-го року випуску. Тобто, продають здебільшого машини, які почали їздити наприкінці 1990-х та на початку 2000-х років. Другий, значно менший пік припадає на машини приблизно 2014-го року випуску – таких машин всього близько 10%.

```{r chart1d, echo=FALSE, warning=FALSE, message=FALSE}
# chart I, base
g <-
  ggplot(df_ua_new, aes(x=year)) +
  geom_density(fill = "maroon", alpha = 0.3, color = "white") + # data for end of january, 2018
  geom_density(data=df_eu_new, fill = "#2b8cbe", alpha = 0.3, color = "white", size=1) +

  geom_density(data=df_eu_old, fill = NA,  color = "#2b8cbe", linetype = 2) +
  geom_density(data=df_ua_old, fill = NA,  color = "maroon", linetype = 2) +

  scale_x_continuous(limits=c(1970, 2020)) +
  theme_ipsum_rc()  

# desktop version
g1 <- g +
  theme(panel.border=element_blank(), plot.background=element_rect(fill=plot_bg, colour = NA), plot.title=element_text(size=14), plot.caption=element_text(size=8, margin=margin(t=5)) ) +
  annotate("text", x=2000.5, y=0.12, label="'Євробляхи'", color = "#999999", fontface="plain", size = 3.5, hjust = "left" ) +
  annotate("text", x=2008, y=0.09, label="Укр. реєстрація", color = "#999999", fontface="plain", size = 3.5, hjust = "left" ) +
  labs(title = "Старим тут місце!", subtitle="Популярність автівок різних років випуску (станом на січень 2018). Пунктир – дані на півроку раніше", caption = "\nTEXTY.ORG.UA", x = "Рік випуску", y = "Щільність розподілу" ) 
  

```

```{r chart1m, message=FALSE, include=FALSE, warning=FALSE, echo=FALSE}


# mobile
g1m <- g + 
theme(panel.border=element_blank(), plot.title=element_text(size=20), 
      plot.caption=element_text(size=18, margin=margin(t=5)),
      axis.text.x = element_text(size = 25),
      axis.text.y = element_blank(),
      axis.title.x = element_text(size = 25, margin = margin(t = 20)),
      axis.title.y = element_text(size = 25, margin = margin(r = -30)) ) +
  
  annotate("text", x=2000.5, y=0.12, label="'Євробляхи'", color = "#999999", fontface="plain", size = 8, hjust = "left" ) +
  annotate("text", x=2008, y=0.09, label="Укр. реєстрація", color = "#999999", fontface="plain", size = 8, hjust = "left" ) +
  
  labs(title = "Популярність автівок різних років випуску", caption = "\nTEXTY.ORG.UA", x = "Рік випуску", y = "Щільність розподілу        " )


  
ggsave(file= paste0(img_dir, "chart-I.svg"), plot = g1, width=11, height=7)
ggsave(file= paste0(img_dir, "chart-I-mobile.png"), plot = g1m, width=11, height=11)
#g1

# see how many autos by year
# ggplot(df_eu_new, aes(x = year)) + stat_ecdf(geom = "step") + scale_x_continuous(limits = c(1980, 2020))

```

![Роки випуску машин](img/chart-I.png){.full-width .hidden-xs .visible-sm .visible-md .visible-lg .visible-xl}
![Роки випуску машин](img/chart-I-mobile.png){.full-width .hidden-sm .visible-xs .hidden-md .hidden-lg .hidden-xl}

Пунктиром вказані схожі дані, але зібрані на півроку раніше. Порівняно із минулим, наразі кількість пропозицій для "новіших” машин з єврономерами зменшилась, також трохи впала кількість пропозицій на старі (до 2000-го року випуску) машини з українською реєстрацією. Схоже, що з часом --- якщо ситуація збережеться --- цей сегмент і надалі буде зменшуватися під тиском пропозицій авто, пригнаних із країн Євросоюзу.


Євробляхи та українські номери відрізняються і за моделями популярних автівок. Серед оголошень з українською реєстрацією лідерами є наступні марки: _Daewoo Lanos(2007), Skoda Octavia A5(2012), Renault Megane(2012), Volkswagen Passat B7(2012), Chevrolet Aveo(2008), Toyota Camry(2008)_.


```{r n1, include=FALSE, message=FALSE, warning=FALSE, echo=FALSE}
df_ua_new %>%
  group_by(modelId, year) %>%
  summarise(amount = n(), name = tail(markName, 1), model = tail(modelName, 1) ) %>%
  arrange(desc(amount)) %>%
  head(10)
```

Натомість, найбільш популярними автівками на “євробляхах” є _Volkswagen Passat B5(1998-2000), Audi A6(2000-2002), Opel Vectra B(2000), Renault Laguna(2002), Volkswagen Golf IV(2002)_.

```{r n2, include=FALSE, message=FALSE, warning=FALSE, echo=FALSE}
df_eu_new %>%
  group_by(modelId, year) %>%
  summarise(amount = n(), name = tail(markName, 1), model = tail(modelName, 1) ) %>%
  arrange(desc(amount)) %>%
  head(10)
```


### Ціна машин


Ми запитали у людей, які мають стосунок до торгівлі автомобілями з Європи: що найкраще продається? Відповідь – все, що в діапазоні від 1.5 до 4 тисяч доларів.

Зазвичай, гроші на купівлю “нової” машини на “євробляхах” люди отримують від продажу старшої на 7-10 років, але з українською реєстрацією. Графік, який ви бачите нижче, підтверджує цю інформацію. Найпопулярніші “євробляхи” – це справді машини у такому інтервалі, і найбільше їх продається за ціною 2-2.5 тисячі доларів (ціна в Європі у таких машин менша приблизно на 500 доларів. Саме такою є типова “дельта” продавців, які приганяють ці машини в Україну)


```{r n3, include=FALSE, message=FALSE, warning=FALSE, echo=FALSE}


group_size <- 9
sigma_max <- 0.2

group_price <- function(df, group_size, sigma_max){
  df %>%
  select(modelId, year, markName, modelName, USD) %>%
  ungroup() %>%
  group_by(modelId, year) %>% 
  summarise(amount = n(), name = tail(markName, 1), model = tail(modelName, 1), price=mean(USD), sigma = sd(USD) ) %>%
  filter(amount >= group_size, sigma < price * sigma_max) %>%
  arrange(desc(amount))
}

# calculate price for each model/year, take only group > some min  group_size, sigma < sigma_max (%)
# df_ua <- df_ua_new %>%
#   select(modelId, year, markName, modelName, USD) %>%
#   ungroup() %>%
#   group_by(modelId, year) %>% 
#   summarise(amount = n(), name = tail(markName, 1), model = tail(modelName, 1), price=mean(USD), sigma = sd(USD) ) %>%
#   filter(amount >= group_size, sigma < price * sigma_max) %>%
#   arrange(desc(amount))


df_ua <- group_price(df_ua_new, group_size, sigma_max )
df_eu <- group_price(df_eu_new, group_size, sigma_max )
df_ua_prev <- group_price(df_ua_old, group_size, sigma_max )
df_eu_prev <- group_price(df_eu_old, group_size, sigma_max )


```

```{r n4, include=FALSE, message=FALSE, warning=FALSE, echo=FALSE}
##########  chart II
g <-
  ggplot() +
  geom_density(data = df_eu, aes(x = price), fill = "#2b8cbe", alpha = 0.3, color = NA) + 
  #geom_density(data = df_old, aes(x = price), fill = "blue", alpha = 0.3, color = NA) +
  geom_density(data = df_ua, aes(x = price), fill = "maroon", alpha = 0.3, color = "white", size = 1.5) +
  
  geom_density(data = df_ua_prev, aes(x = price),  color = "maroon",  linetype=2  ) +
  geom_density(data = df_eu_prev, aes(x = price),  color = "#2b8cbe", linetype=2) +
  
  scale_x_continuous(limits=c(0, 25000)) +
  theme_ipsum_rc() 

g2 <- g +
  theme(panel.border=element_blank(), plot.background=element_rect(fill=plot_bg, colour = NA), plot.title=element_text(size=14), plot.caption=element_text(size=8, margin=margin(t=5)) ) +
  annotate("text", x=2700, y=3.1e-04, label="'Євробляхи'", color = "#999999", fontface="plain", size = 3.5, hjust = "left" ) +
  annotate("text", x=7500, y=1e-04, label="Укр. реєстрація", color = "#999999", fontface="plain", size = 3.5, hjust = "left" ) +
  labs(title = "Найпопулярніші \"євробляхи\": автівки за 2-2,5 тис. доларів", subtitle="Найпоширеніші машини з українською реєстрацією – приблизно на 5 тис. дорожчі", caption = "\nTEXTY.ORG.UA", 
       x = "Ціна, USD", y = "Щільність розподілу" ) +
  theme(axis.ticks.y = element_blank(), axis.text.y = element_blank() ) 

g2mob <- g +
  theme(panel.border=element_blank(), 
        plot.background=element_blank(),
        plot.title=element_text(size=25), 
        plot.caption=element_text(size=18, margin=margin(t=5)), 
        axis.text.x = element_text(size = 25),
        axis.text.y = element_blank(),
        axis.title.x = element_text(size = 25, margin = margin(t = 20)),
        axis.title.y = element_text(size = 25, margin = margin(r = -30)) ) +
  
  annotate("text", x=2700, y=3.1e-04, label="'Євробляхи'", color = "#999999", fontface="plain", size = 8, hjust = "left" ) +
  annotate("text", x=7500, y=1e-04, label="Укр. реєстрація", color = "#999999", fontface="plain", size = 8, hjust = "left" ) +
  
  labs(title = "Найпопулярніші \"євробляхи\": автівки за 2.5 тис.", caption = "\nTEXTY.ORG.UA", 
       x = "Ціна, USD", y = "Щільність розподілу        " ) +
  theme(axis.ticks.y = element_blank(), axis.text.y = element_blank() ) 



ggsave(file= paste0(img_dir, "chart-II.png"), plot = g2, width=11, height=7)
ggsave(file= paste0(img_dir, "chart-II-mobile.png"), plot = g2mob, width=11, height=11)

```
![Ціни машин](img/chart-II.png){.full-width .hidden-xs .visible-sm .visible-md .visible-lg .visible-xl}
![Ціни машин](img/chart-II-mobile.png){.full-width .hidden-sm .visible-xs .hidden-md .hidden-lg .hidden-xl}



### Ціна реєстрації

Скільки коштує зареєструвати машину на українські номери? Навіть без спецмита, майбутній власник “легальної” автівки витрачається на закладені у ціну акцизний збір, ПДВ, ввізне мито, збір до Пенсійного фонду і транспортний податок (за нові авто). Отже, скільки отримує держава з таких угод?
Ми знайшли у даних інформацію по ціні для пар однакових марок машин (та одного віку), одна з яких на “єврономерах”, інша – з українською реєстрацією. На графіку нижче ви можете побачити різницю.

```{r n5, include=FALSE, message=FALSE, warning=FALSE, echo=FALSE}
df_diff <- df_ua %>%
  inner_join( df_eu %>% select( -name, -model ), by = c("modelId", "year") ) %>%
  mutate(price_diff = price.x - price.y, price_diff_relative = price_diff / price.x, year = as.character(year) )  %>%
  arrange( price.x ) 



mean(df_diff$price_diff_relative) # 0.52
median(df_diff$price_diff_relative) # 0.53
```

Як найкраще читати цей графік? Сині точки – ціна моделі на “євробляхах”, червоні – такого ж авто з реєстрацією. Відсоток різниці вказаний на лінії, що їх з’єднує. Моделі відсортовані у порядку збільшення ціни. В коридорах цін (які показані вертикальними лініями) можна вибрати найкращі пропозиції (найбільш ліві сині точки). Наприклад, Mazda 6 2005 року або Skoda Octavia 2004-го – це найкраші варіанти машин за 2.5 тисячі доларів.




```{r n6, dev="svg", message=FALSE, warning=FALSE, echo=FALSE}
# create fake point for legend
legend <- df_diff[1, ]
legend["price.x"] <- 23000
legend["price.y"] <- 17000
legend["name"] <- ""
legend["model"] <- ""
legend["year"] <- ""


#df_diff <- rbind(legend, df_diff )

# common base for a plot
g3 <- function(df) { 
  rbind(legend, df) %>%
  ungroup() %>%  
  mutate(ypos = as.numeric(row.names(.))) %>%  
  ggplot( aes(y=ypos ) ) +
  
  geom_segment(aes(x=price.y, y=ypos, xend=price.x, yend=ypos), color = "#bebebe", size = 0.5) +
  geom_point(aes(x=price.x + 100), color="maroon", shape = 1, size = 2.5, stroke = 1.5) +
  geom_point(aes(x=price.y - 100), color="#2b8cbe", shape = 1, size = 2.5, stroke = 1.5) +
  
  
  
  #scale_x_continuous(limits=c(0, 25000)) +
  scale_x_continuous(name = "Ціна, USD", breaks=seq.int(0, 25000, 2500), limits=c(0, 25000)) +
  #scale_y_continuous(limits=c(NA, 50)) +
  theme_ipsum_rc(ticks = F, grid = T, axis = F ) +
  
  
  theme(axis.line.y = element_blank(), 
        axis.title.y = element_blank(), 
        axis.text.y = element_blank(), 
        panel.grid.major.y = element_blank(),
        panel.grid.minor.y = element_blank(),
        panel.grid.minor.x = element_line( linetype = 2),
        panel.grid.major.x = element_line( linetype = 2))  
  
}  

  
# desktop version  
g3base <-   g3(df_diff) +
        labs(title = "...І п’ятдесят відсотків зверху", subtitle="Різниця в ціні для однакових моделей авто з українською реєстрацією та без неї", caption = "\nTEXTY.ORG.UA") +
        theme(panel.border=element_blank(), 
        plot.background=element_rect(fill=plot_bg, colour = NA),
        plot.title=element_text(size=14), 
        plot.caption=element_text(size=8, margin=margin(t=5)) ) +
  

  geom_text(aes(x=price.x + 500, y = ypos, label=paste(name, model, year) ), hjust="left", color = "#999999", size = 3.5) +
  geom_label(aes(x=(price.y + price.x)/2, y=ypos, label= paste0(as.integer( 100*price_diff_relative),"%")  ), size = 3,  label.size = 0, color = "#777777", 
             hjust="center", label.padding = unit(0.25, "lines")) 
  

# add legend  
g3base_l <-  g3base + 
  annotate("text", x=17000, y=2, label="Ціна, єврономери", color = "#999999", fontface="plain", size = 3.5 ) +
  annotate("text", x=20000, y=2, label="Різниця, %", color = "#999999", size = 3.5) +
  annotate("text", x=23000, y=2, label="Ціна, укр.номери", color = "#999999", size = 3.5)


ggsave(file= paste0(img_dir, "chart-III.png"), plot=g3base_l, width=11, height=14)

###################### mobile version ########################

g3mob <-   g3(df_diff %>% sample_frac(0.5) %>% arrange(price.x) ) +
        labs(title = "Різниця у ціні автомобілів з реєстрацією та без неї", caption = "\nTEXTY.ORG.UA") +
        theme(panel.border=element_blank(), 
        plot.background=element_blank(), 
        plot.title=element_text(size=25), 
        plot.caption=element_text(size=18, margin=margin(t=5)), 
        axis.title.x = element_text(size = 15),
        axis.text.x = element_text(size = 15)
        ) +
  

  geom_text(aes(x=price.x + 500, y = ypos, label=paste(name, model, year) ), hjust="left", color = "black", size = 7.2) +
  geom_label(aes(x=(price.y + price.x)/2, y=ypos, label= paste0(as.integer( 100*price_diff_relative),"%")  ), size = 7.2,  label.size = 0, color = "#777777", 
             hjust="center", label.padding = unit(0.25, "lines")) 
  

# add legend  
g3mob_l <-  g3mob + 
  annotate("text", x=16500, y=2, label="Єврономери, \nціна", color = "black", fontface="plain", size = 4, hjust = "left" ) +
  annotate("text", x=19500, y=2, label="Різниця, %", color = "black", size = 4, hjust = "left") +
  annotate("text", x=22500, y=2, label="Укр.номери, \nціна", color = "black", size = 4, hjust = "left")


ggsave(file= paste0(img_dir, "chart-III-mobile.png"), plot=g3mob_l, width=11, height=11)



```


![Різниця у ціні](img/chart-III.png){.full-width .hidden-xs .visible-sm .visible-md .visible-lg .visible-xl}
![Різниця у ціні](img/chart-III-mobile.png){.full-width .hidden-sm .visible-xs .hidden-md .hidden-lg .hidden-xl}


В середньому виходить, що ви платите за машину з реєстрацією удвічі більше (на ~`r floor(mean(100*df_diff$price_diff_relative))`% більше). Недивно, що українські громадяни ризикують отримати штраф або втратити свою власність внаслідок крадіжки, але все-таки купити авто на “євробляхах”. “Ціна держави”, як це часто у нас буває, болісно велика.

До того ж, проблема вже стала політичною: власники 300 тис. (або 1 млн. – за неофіційною оцінкою) таких машин можуть наробити неприємностей будь-якій політичній силі, яка спробує радикально розібратися з “єврономерами”.

У випадку, якщо питання реєстрації врегулюють за допомогою внесення якоїсь фіксованої платні за автівки з єврономерами, ціни всіх машин можуть встановитися на рівні поточна ціна авто на “єврономерах” + фіксована платня. Це також означатиме, що машини з українською реєстрацією після такого рішення можуть суттєво впасти у ціні (від приблизно 30% для новіших і дорожчих машин, до 50% для старіших, як це видно із графіка).



[^1]: _["Замовити білоруса", Texty.org.ua, квітень 2017](http://texty.org.ua/pg/article/editorial/read/76098/){.dotted}_
[^2]: _[Дані з сайту auto.ria.com - клікніть щоб отримати їх собі](http://texty.org.ua/d/auto_euro/data/data.zip){.dotted}_
[^3]: _Ви можете перевірити цей матеріал, відтворивши його на своєму комп'ютері. [Код для статті, з інструкцією всередині](http://texty.org.ua/d/auto_euro/article.Rmd){.dotted}_

_Фото від LoboStudio, Гамбург_


